==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectProxyNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectProxyNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 659cb4f795087eae soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$java__5flang__5freflect__5fProxy__5fdefineClass0$3759f33b030a74dd(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$v$57a85f2ddb69e2b3(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaLangReflectProxyNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaLangReflectProxyNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 659cb4f795087eae soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$java__5flang__5freflect__5fProxy__5fdefineClass0$3759f33b030a74dd(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$method$v$57a85f2ddb69e2b3(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaLangReflectProxyNative_H_ */
